"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const path = require("path");
const errors_1 = require("./../errors");
const guards_1 = require("../guards");
const fs_1 = require("./fs");
exports.PACKAGE_JSON_FILE = 'package.json';
async function readPackageJson(dir, exceptionType = 'user') {
    try {
        const f = await fs_1.fsReadFile(path.resolve(dir, exports.PACKAGE_JSON_FILE), { encoding: 'utf8' });
        const o = JSON.parse(f);
        if (!guards_1.isPackageJson(o)) {
            throw new errors_1.JobException(`Invalid format in ${exports.PACKAGE_JSON_FILE}.`, exceptionType);
        }
        return o;
    }
    catch (e) {
        if (e.code === 'ENOENT') {
            throw new errors_1.JobException(`Missing ${exports.PACKAGE_JSON_FILE} in app.`, exceptionType);
        }
        else if (e instanceof SyntaxError) {
            throw new errors_1.JobException(`Invalid JSON in ${exports.PACKAGE_JSON_FILE}.`, exceptionType);
        }
        throw e;
    }
}
exports.readPackageJson = readPackageJson;
